ErrorLVT

Struct ErrorLVT 

pub struct ErrorLVT { /* private fields */ }
Error Vector Table Entry.

Implementations

Source

impl ErrorLVT

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl ErrorLVT

pub const fn into_bytes(self) -> [u8; 16]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 16]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl ErrorLVT

pub fn vector(&self) -> <u8 as Specifier>::InOut

Returns the value of vector.

pub fn vector_or_err( &self, ) -> Result<<u8 as Specifier>::InOut, InvalidBitPattern<<u8 as Specifier>::Bytes>>

Returns the value of vector.

#Errors

If the returned value contains an invalid bit pattern for vector.

pub fn with_vector(self, new_val: <u8 as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of vector set to the given value.

#Panics

If the given value is out of bounds for vector.

pub fn with_vector_checked( self, new_val: <u8 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of vector set to the given value.

#Errors

If the given value is out of bounds for vector.

pub fn set_vector(&mut self, new_val: <u8 as Specifier>::InOut)

Sets the value of vector to the given value.

#Panics

If the given value is out of bounds for vector.

pub fn set_vector_checked( &mut self, new_val: <u8 as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of vector to the given value.

#Errors

If the given value is out of bounds for vector.

pub fn delivery_status(&self) -> <B1 as Specifier>::InOut

Returns the value of delivery_status.

pub fn delivery_status_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>

Returns the value of delivery_status.

#Errors

If the returned value contains an invalid bit pattern for delivery_status.

pub fn with_delivery_status(self, new_val: <B1 as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of delivery_status set to the given value.

#Panics

If the given value is out of bounds for delivery_status.

pub fn with_delivery_status_checked( self, new_val: <B1 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of delivery_status set to the given value.

#Errors

If the given value is out of bounds for delivery_status.

pub fn set_delivery_status(&mut self, new_val: <B1 as Specifier>::InOut)

Sets the value of delivery_status to the given value.

#Panics

If the given value is out of bounds for delivery_status.

pub fn set_delivery_status_checked( &mut self, new_val: <B1 as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of delivery_status to the given value.

#Errors

If the given value is out of bounds for delivery_status.

pub fn mask(&self) -> <B1 as Specifier>::InOut

Returns the value of mask.

pub fn mask_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>

Returns the value of mask.

#Errors

If the returned value contains an invalid bit pattern for mask.

pub fn with_mask(self, new_val: <B1 as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of mask set to the given value.

#Panics

If the given value is out of bounds for mask.

pub fn with_mask_checked( self, new_val: <B1 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of mask set to the given value.

#Errors

If the given value is out of bounds for mask.

pub fn set_mask(&mut self, new_val: <B1 as Specifier>::InOut)

Sets the value of mask to the given value.

#Panics

If the given value is out of bounds for mask.

pub fn set_mask_checked( &mut self, new_val: <B1 as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of mask to the given value.

#Errors

If the given value is out of bounds for mask.